@@ -8,6 +8,7 @@
 
 // Header files
 #include <RcppArmadillo.h>
+#include "redist_types.h"
 #include "make_swaps_helper.h"
 #include "constraint_calc_helper.h"
 
@@ -15,14 +16,14 @@ using namespace Rcpp;
 
 // Function to generate initial vector of populations
 NumericVector init_pop(NumericVector popvec,
-		       arma::vec cds)
+                       arma::vec cds)
 {
 
   /* Inputs to function:
-     cds: Vector of congressional district populations
+   cds: Vector of congressional district populations
 
-     popvec: Vector of populations
-  */ 
+   popvec: Vector of populations
+   */
 
   // Get number of cds
   int ncds = cds.max() + 1;
@@ -39,9 +40,9 @@ NumericVector init_pop(NumericVector popvec,
     // Initialize population count
     pop = 0;
 
-    // Get indices of cds 
+    // Get indices of cds
     cd_i_ind = find(cds == i);
-    
+
     // Loop through cd_i_ind, get population values
     for(j = 0; j < cd_i_ind.n_elem; j++){
       pop += popvec(cd_i_ind(j));
@@ -61,32 +62,32 @@ List add_ties(List aList){
 
   // Initialize
   int i; NumericVector list1; int j; NumericVector list2;
-  
+
   // Loop through vectors in aList
   for(i = 0; i < aList.size(); i++){
 
     // Get i'th entry in list
     list1 = aList(i);
-    
+
     // Loop through elements in list1
     for(j = 0; j < list1.size(); j++){
 
       // Extract adjacency vector for j'th element of i's adjacency list
       list2 = aList(list1(j));
-      
+
       // Check if list 2 includes i
       if(is_true(any(list2 == i)) == FALSE){
 
-	// If not included, add to adjacency vector
-	list2.push_back(i);
+        // If not included, add to adjacency vector
+        list2.push_back(i);
 
-	// Modify aList to include new adjacency vector
-	aList(list1(j)) = list2;
+        // Modify aList to include new adjacency vector
+        aList(list1(j)) = list2;
 
       }
-    
+
     }
- 
+
   }
 
   return aList;
@@ -95,14 +96,14 @@ List add_ties(List aList){
 
 // Function to cut edges of adjacency list probabilistically - Step 2 of swMH
 List cut_edges(List aList_con,
-	       double eprob)
+               double eprob)
 {
 
   /* Inputs to function:
-     aList_con: adjacency list within cong district
+   aList_con: adjacency list within cong district
 
-     eprob: edgecut probability (transformed into 1-eprob in function)
-  */
+   eprob: edgecut probability (transformed into 1-eprob in function)
+   */
 
   // Create threshold
   double threshold_prob = 1.0 - eprob;
@@ -113,7 +114,7 @@ List cut_edges(List aList_con,
 
   // Initialize inside loop
   int i; NumericVector cc_vec_i_all; NumericVector cc_vec_i;
-  arma::vec draws; 
+  arma::vec draws;
 
   // Define list to store output of both lists
 
@@ -135,26 +136,26 @@ List cut_edges(List aList_con,
 
     // Loop through elements of cc_vec_i and compare to entry in draws
     for(int j = 0; j < cc_vec_i.size(); j++){
-      
+
       // Compare to threshold_prob - if draws < thresh, cut edge, else uncut
       if(draws(j) < threshold_prob){
-	cut.push_back(cc_vec_i(j));
+        cut.push_back(cc_vec_i(j));
       } else{
-	uncut.push_back(cc_vec_i(j));
+        uncut.push_back(cc_vec_i(j));
       }
 
     }
 
     /* Here - look at lines 1201-1212 in original code. Modifying original
-       alConnected to remove edges that are cut, but isn't this just the 
-       uncut list (which will be aList_postcut? Skipping this bit for now */
-    
+     alConnected to remove edges that are cut, but isn't this just the
+     uncut list (which will be aList_postcut? Skipping this bit for now */
+
     // Store vectors in container lists
     aList_uncut(i) = uncut;
     aList_cut(i) = cut;
 
   }
-  
+
   // Add ties to aList_uncut, aList_cut
   List aList_uncut_bd = add_ties(aList_uncut);
   List aList_cut_bd = add_ties(aList_cut);
@@ -163,22 +164,22 @@ List cut_edges(List aList_con,
   List out;
   out["connectedlist"] = aList_uncut_bd;
   out["cutedgelist"] = aList_cut_bd;
-  
+
   return out;
 
 }
 
-/* Function to run breadth-first search, returning only sets of connected 
-   components that reside on the boundary of the districts */
+/* Function to run breadth-first search, returning only sets of connected
+ components that reside on the boundary of the districts */
 List bsearch_boundary(List aList,
-		      arma::vec boundary)
+                      arma::vec boundary)
 {
 
   /* Inputs to function:
-     aList: adjacency list
+   aList: adjacency list
 
-     boundary: vector of boundary element indicators (as arma)
-  */
+   boundary: vector of boundary element indicators (as arma)
+   */
 
   // Get indices of boundary units
   arma::uvec boundary_indices = find(boundary == 1);
@@ -201,14 +202,14 @@ List bsearch_boundary(List aList,
   q = aList(boundary_indices(0));
 
   // Initialize objects inside loop
-  int u; bool in_part; NumericVector adj_u; int i; int v; 
+  int u; bool in_part; NumericVector adj_u; int i; int v;
 
   // Begin do{} loop - run until number of elements in boundary_indices is 0
   do{
 
     // Begin while{} loop - run until q is empty
     while(q.size() > 0){
-      
+      Rcpp::checkUserInterrupt();
       // Dequeue first element in queue
       u = q(0);
 
@@ -218,30 +219,30 @@ List bsearch_boundary(List aList,
       // Check if element is in the partition - add to partition if false
       in_part = is_true(any(partition == u));
       if(in_part == false){
-	partition.push_back(u);
+        partition.push_back(u);
       }
-      
+
       // Get adjacency vector for unit u
       adj_u = aList(u);
 
       // Loop through elements of adj_u, add to queue and mark if not reached
       if(adj_u.size() > 0){
-	
-	// Start loop
-	for(i = 0; i < adj_u.size(); i++){
-	  
-	  // Reach element v
-	  v = adj_u(i);
 
-	  /* Check if already reached - if false, mark, add to partition, and
-	     add to queue */
-	  if(is_true(any(mark == v)) == FALSE){
-	    mark(v) = v;
-	    partition.push_back(v);
-	    q.push_back(v);
-	  }
+        // Start loop
+        for(i = 0; i < adj_u.size(); i++){
 
-	}
+          // Reach element v
+          v = adj_u(i);
+
+          /* Check if already reached - if false, mark, add to partition, and
+           add to queue */
+          if(is_true(any(mark == v)) == FALSE){
+            mark(v) = v;
+            partition.push_back(v);
+            q.push_back(v);
+          }
+
+        }
 
       }
 
@@ -254,22 +255,22 @@ List bsearch_boundary(List aList,
     if(q.size() == 0){
 
       /* First, find boundary units that are in the reached partition and
-	 remove them from boundary_units vector */
+       remove them from boundary_units vector */
       for(i = boundary_indices.n_elem - 1; i >= 0; i--){
-	if(is_true(any(partition == boundary_indices(i))) == TRUE){
-	  boundary_indices.shed_row(i);
-	}
+        if(is_true(any(partition == boundary_indices(i))) == TRUE){
+          boundary_indices.shed_row(i);
+        }
       }
-      
+
       // Store the partition, clear partition vector
       bsearch.push_back(partition);
       partition.erase(partition.begin(), partition.end());
 
       // Re-initialize breadth search from new starting value if nonempty
       if(boundary_indices.n_elem > 0){
-	q = aList(boundary_indices(0));
-	mark(boundary_indices(0)) = boundary_indices(0);
-	partition.push_back(boundary_indices(0));
+        q = aList(boundary_indices(0));
+        mark(boundary_indices(0)) = boundary_indices(0);
+        partition.push_back(boundary_indices(0));
       }
 
     }
@@ -298,21 +299,21 @@ int count_valid(List aList, List boundarypart, NumericVector cdvec){
   arma::uvec find_cds; int counter = 0;
 
   for(i = 0; i < boundarypart.size(); i++){
-    
+
     // Get the partition
     part = as<arma::vec>(boundarypart(i));
-    
+
     // Get the congressional district of the boundary
     cd_boundary = cdvec(part(0));
-    
+
     // Find indices within that congressional district
     find_cds = find(as<arma::vec>(cdvec) == cd_boundary);
-    
+
     // Remove elements in the partition from that cd
     NumericVector cd_less_boundary;
     for(j = 0; j < find_cds.n_elem; j++){
       if(any(part == find_cds(j)) == false){
-	cd_less_boundary.push_back(find_cds(j));
+        cd_less_boundary.push_back(find_cds(j));
       }
     }
 
@@ -321,45 +322,45 @@ int count_valid(List aList, List boundarypart, NumericVector cdvec){
     if(cd_less_boundary.size() == 0){
       continue;
     }
-    
+
     // Create new adjacency list
     List newadj(cd_less_boundary.size());
     for(j = 0; j < newadj.size(); j++){
-      
+
       // Extract vector from adjacency list
       NumericVector getadjvec = aList(cd_less_boundary(j));
-      
+
       // Subset down to elements in cd_less_boundary
       NumericVector getadjvec_sub;
       for(int k = 0; k < getadjvec.size(); k++){
-	if(any(as<arma::vec>(cd_less_boundary) == getadjvec(k))){
-	  getadjvec_sub.push_back(getadjvec(k));
-	}
+        if(any(as<arma::vec>(cd_less_boundary) == getadjvec(k))){
+          getadjvec_sub.push_back(getadjvec(k));
+        }
       }
-      
+
       // Change indices
       NumericVector getadjvec_new;
       for(int k = 0; k < getadjvec_sub.size(); k++){
-	arma::uvec ind = find(as<arma::vec>(cd_less_boundary) ==
-			      getadjvec_sub(k));
-	getadjvec_new.push_back(ind(0));
+        arma::uvec ind = find(as<arma::vec>(cd_less_boundary) ==
+          getadjvec_sub(k));
+        getadjvec_new.push_back(ind(0));
       }
-      
+
       // Add to newadj
       newadj(j) = getadjvec_new;
-      
+
     }
-    
+
     // Calculate number of partitions
     int nparts = countpartitions(newadj);
     if(nparts == 1){
       counter++;
     }
-    
+
   }
-  
+
   return counter;
-  
+
 }
 
 /* Function to draw p for the number of connected components */
@@ -367,8 +368,8 @@ int draw_p(int lambda)
 {
 
   /* Inputs to function:
-     lambda: lambda parameter
-  */
+   lambda: lambda parameter
+   */
 
   int p;
   if(lambda > 0){
@@ -383,69 +384,86 @@ int draw_p(int lambda)
 }
 
 /* Function to draw p separate, noncontiguous connected components from the
-   output of the boundary breadth search. These are candidate swaps
-   to form the next iteration of the markov chain. Function returns
-   the proposed district assignments that will be accepted or rejected */
+ output of the boundary breadth search. These are candidate swaps
+ to form the next iteration of the markov chain. Function returns
+ the proposed district assignments that will be accepted or rejected */
 List make_swaps(List boundary_cc,
-		List aList, 
-		NumericVector cds_old,
-		NumericVector cds_orig,
-		NumericVector pop_vec, 
-		NumericVector cd_pop_vec,
-		NumericVector group_pop_vec,
-		NumericVector areas_vec,
-		arma::mat borderlength_mat,
-		NumericMatrix ssdmat,
-		NumericVector county_membership,
-		double minparity,
-		double maxparity, 
-		int p, 
-		double eprob,
-		double beta,
-		double weight_population,
-		double weight_compact,
-		double weight_segregation,
-		double weight_similar,
-		double weight_countysplit,
-		double ssd_denominator,
-		std::string compactness_measure)
+                List aList,
+                NumericVector cds_old,
+                NumericVector cds_orig,
+                NumericVector pop_vec,
+                NumericVector cd_pop_vec,
+                NumericVector group_pop_vec,
+                NumericVector areas_vec,
+                arma::mat borderlength_mat,
+                NumericMatrix ssdmat,
+                IntegerVector county_membership,
+                double minparity,
+                double maxparity,
+                int p,
+                double eprob,
+                double beta,
+                double weight_population,
+                double weight_compact,
+                double weight_segregation,
+                double weight_vra,
+                double weight_similar,
+                double weight_countysplit,
+                double weight_partisan,
+                double weight_minority,
+                double weight_hinge,
+                double ssd_denominator,
+                double tgt_min,
+                double tgt_other,
+                IntegerVector rvote,
+                IntegerVector dvote,
+                NumericVector minorityprop,
+                std::string compactness_measure,
+                std::string partisan_measure,
+                const Graph &g)
 {
 
   /* Inputs to function:
-     boundary_cc: Connected components on district boundaries
+   boundary_cc: Connected components on district boundaries
 
-     aList: full adjacency list
+   aList: full adjacency list
 
-     cds_old: Current cong district assignments
+   cds_old: Current cong district assignments
 
-     cds_orig: original cong district assignments. For similarity constraint
+   cds_orig: original cong district assignments. For similarity constraint
 
-     pop_vec: unit populations
+   pop_vec: unit populations
 
-     cd_pop_vec: congressional district populations
+   cd_pop_vec: congressional district populations
 
-     group_pop_vec: populations of groups in geographic units
+   group_pop_vec: populations of groups in geographic units
 
-     ssdmat: sum of squared distance matrix
+   ssdmat: sum of squared distance matrix
 
-     minparity, maxparity: population parity - min and max
+   minparity, maxparity: population parity - min and max
 
-     p: parameter p for the number of swaps
+   p: parameter p for the number of swaps
 
-     eprob: edgecut probability
+   eprob: edgecut probability
 
-     beta_population: strength of constraint for achieving population parity.
+   beta_population: strength of constraint for achieving population parity.
 
-     beta_compact: strength of constraint for achieving compactness
+   beta_compact: strength of constraint for achieving compactness
 
-     beta_segregation: strength of constraint for segregating subgroup
+   beta_segregation: strength of constraint for segregating subgroup
 
-     beta_similar: strength of constraint for similarity to orig plan
+   beta_vra: strength of constraint for segregating subgroup
 
-     ssd_denominator: normalizing constant for sum of squared distance psi
+   beta_partisan: strength of constraint for minimizing partisan bias measure
+
+   beta_similar: strength of constraint for similarity to orig plan
+
+   ssd_denominator: normalizing constant for sum of squared distance psi
+
+   partisan_measure: string, only "efficiency-gap" implemented thus far
+
+   */
 
-  */
-  
   // Initialize objects for swap //
   NumericVector cds_prop = clone(cds_old);
   NumericVector cdspop_prop = clone(cd_pop_vec);
@@ -462,19 +480,27 @@ List make_swaps(List boundary_cc,
   double compact_old_psi = 0.0;
   double segregation_new_psi = 0.0;
   double segregation_old_psi = 0.0;
+  double vra_new_psi = 0.0;
+  double vra_old_psi = 0.0;
   double similar_new_psi = 0.0;
   double similar_old_psi = 0.0;
   double countysplit_new_psi = 0.0;
   double countysplit_old_psi = 0.0;
+  double partisan_new_psi = 0.0;
+  double partisan_old_psi = 0.0;
+  double minority_new_psi = 0.0;
+  double minority_old_psi = 0.0;
+  double hinge_new_psi = 0.0;
+  double hinge_old_psi = 0.0;
 
   // Number of unique congressional districts
   int ndists = max(cds_old) + 1;
 
   // Break indicators
-  int breakp = 0; 
+  int breakp = 0;
   int numaccept = 0;
   int goodprop = 0;
-  
+
   // Begin loop over p
   for(int i = 0; i < p; i++){
 
@@ -484,6 +510,7 @@ List make_swaps(List boundary_cc,
     int prop_cd;
     NumericVector prop_partitions;
     while(boundary_cc.size() > 0){
+      Rcpp::checkUserInterrupt();
       
       // (1) - select a connected component from boundary_cc randomly
       arma::vec rand_sample_index = runif(1, 0, 1000000000);
@@ -492,176 +519,197 @@ List make_swaps(List boundary_cc,
       prop_partitions = boundary_cc(sample_index);
       boundary_cc.erase(sample_index);
       curr_cd = cds_prop(prop_partitions(0));
-      
+
       /* (2) - check to see if that connected component is adjacent to one
-	 already selected. Also, gathers adjacent congressional districts */
-      List adjcheck_out = adjcheck_propcd(aList, 
-					  prop_partitions,
-					  accepted_partitions,
-					  cds_prop);
-      
+       already selected. Also, gathers adjacent congressional districts */
+      List adjcheck_out = adjcheck_propcd(aList,
+                                          prop_partitions,
+                                          accepted_partitions,
+                                          cds_prop);
+
       // If adjacent to already-accepted unit, then invalid - return to top
       int adjcheck = as<int>(adjcheck_out["adjacency_check"]);
       if(adjcheck == 1){
-	continue;
+        continue;
       }
 
       /* (3) - Check to see if the proposed swap eliminates its old
-	 congressional district, conditional on valid previous swaps. 
-	 If invalid, return to the top */
+       congressional district, conditional on valid previous swaps.
+       If invalid, return to the top */
       int elimcheck = elim_check(prop_partitions, cds_prop);
       if(elimcheck == 1){
-	continue;
+        continue;
       }
 
-      /* (4) - check to see if the proposed swap splits its old 
-	 congressional district - make arbitrary cd assignment just to 
-	 test (this is not the sample stage) */
+      /* (4) - check to see if the proposed swap splits its old
+       congressional district - make arbitrary cd assignment just to
+       test (this is not the sample stage) */
       // Preprocess by arbitrarily assigning prop_partition to new cd
       NumericVector possible_cd_swaps = as<NumericVector>(adjcheck_out["proposed_cds"]);
       NumericVector cds_splittest = clone(cds_prop);
       for(int j = 0; j < prop_partitions.size(); j++){
-	cds_splittest(prop_partitions(j)) = possible_cd_swaps(0);
+        cds_splittest(prop_partitions(j)) = possible_cd_swaps(0);
       }
       // Get adjacency list
       List aList_testsplit = genAlConn(aList, cds_splittest);
       // Get number of connected components
       int num_cds = countpartitions(aList_testsplit);
       if(num_cds != ndists){
-	continue;
+        continue;
       }
-      
+
       // (5) - propose to swap into a new (adjacent) congressional district
       int numcds_test = possible_cd_swaps.size();
-      
+
       // Loop over elements in propcds - try each one
       for(int j = 0; j < numcds_test; j++){
 
-	// Draw an element from possible_cds_swaps
-	if(possible_cd_swaps.size() > 1){
-	  arma::vec rand_test_cd_ind = runif(1, 0, 1000000000);
-	  int test_cd_ind = fmod(rand_test_cd_ind(0), possible_cd_swaps.size());
-	  
-	  prop_cd = possible_cd_swaps(test_cd_ind);
-	  possible_cd_swaps.erase(test_cd_ind);
-	} else{
-	  prop_cd = possible_cd_swaps(0);
-	  possible_cd_swaps.erase(0);
-	}
-	
-	// Create a test cd vector - change cds of test partition to prop_cd
-	cds_test = clone(cds_prop);
-	for(int k = 0; k < prop_partitions.size(); k++){
-	  cds_test(prop_partitions(k)) = prop_cd;
-	}
+        // Draw an element from possible_cds_swaps
+        if(possible_cd_swaps.size() > 1){
+          arma::vec rand_test_cd_ind = runif(1, 0, 1000000000);
+          int test_cd_ind = fmod(rand_test_cd_ind(0), possible_cd_swaps.size());
 
-	/* (6) - Check to see if proposed swap would violate the imposed
-	   population constraint */
-	prop_cd_pops = update_distpop(prop_partitions, 
-				      pop_vec, 
-				      prop_cd, 
-				      curr_cd,
-				      cdspop_prop);
+          prop_cd = possible_cd_swaps(test_cd_ind);
+          possible_cd_swaps.erase(test_cd_ind);
+        } else{
+          prop_cd = possible_cd_swaps(0);
+          possible_cd_swaps.erase(0);
+        }
+
+        // Create a test cd vector - change cds of test partition to prop_cd
+        cds_test = clone(cds_prop);
+        for(int k = 0; k < prop_partitions.size(); k++){
+          cds_test(prop_partitions(k)) = prop_cd;
+        }
+
+        /* (6) - Check to see if proposed swap would violate the imposed
+         population constraint */
+        prop_cd_pops = update_distpop(prop_partitions,
+                                      pop_vec,
+                                      prop_cd,
+                                      curr_cd,
+                                      cdspop_prop);
+
+        int paritycheck = 0;
+        int k;
+        for(k = 0; k < prop_cd_pops.size(); k++){
+          if((prop_cd_pops(k) >= minparity) && (prop_cd_pops(k) <= maxparity)){
+            paritycheck++;
+          }
+        }
+        if(paritycheck == prop_cd_pops.size()){
+          breakwhile++;
+          numaccept++;
+          break;
+        }
 
-	int paritycheck = 0;
-	int k;
-	for(k = 0; k < prop_cd_pops.size(); k++){
-	  if((prop_cd_pops(k) >= minparity) && (prop_cd_pops(k) <= maxparity)){
-	    paritycheck++;
-	  } 
-	}
-	if(paritycheck == prop_cd_pops.size()){
-	  breakwhile++;
-	  numaccept++;
-	  break;
-	}
-	
       }
 
       // Check for if we have enough valid swaps
       if(numaccept == p){
-	goodprop++;
-	breakp++;
-	break;
+        goodprop++;
+        breakp++;
+        break;
       }
-      
+
       // If good proposal, but need more
       if(breakwhile == 1){
-	break;
+        break;
       }
-      
+
     }
 
     // If we run out of good partitions
     if((boundary_cc.size() == 0) & (numaccept < p)){
       break;
     }
-    
+
     /////////////////////////////////////////////////////////////////////////////////////
     // Accept if (2-6) are satisfied. First, update mh_prob and all constraints. Then, //
     // change cds_prop, cd_pop_vec, and add to accepted_partitions //////////////////////
     /////////////////////////////////////////////////////////////////////////////////////
-    
+
     // Create vector of the cong district swap. First entry is old district, second entry
     // is proposed district
     NumericVector cd_pair(2);
     cd_pair(0) = curr_cd;
     cd_pair(1) = prop_cd;
-    
+
     // Update metropolis-hastings probabilities
     mh_prob = update_mhprob(prop_partitions,
-			    aList,
-			    cds_prop,
-			    prop_cd,
-			    eprob,
-			    mh_prob);
-    
+                            aList,
+                            cds_prop,
+                            prop_cd,
+                            eprob,
+                            mh_prob);
+
     // Calculate beta constraints
     List population_constraint;
     List compact_constraint;
     List segregation_constraint;
+    List vra_constraint;
     List similar_constraint;
+    List partisan_constraint;
+    List minority_constraint;
+    List hinge_constraint;
     if(weight_population != 0.0){
 
       population_constraint = calc_psipop(cds_prop, cds_test, pop_vec, cd_pair);
 
       pop_new_psi += as<double>(population_constraint["pop_new_psi"]);
       pop_old_psi += as<double>(population_constraint["pop_old_psi"]);
-      
+
     }
     if(weight_compact != 0.0){
-      
-      compact_constraint = calc_psicompact(cds_prop, cds_test,
-					   cd_pair, compactness_measure,
-					   aList, areas_vec,
-					   borderlength_mat, true,
-					   pop_vec, ssdmat, ssd_denominator);
+
+      compact_constraint = calc_psicompact(cds_prop,
+                                           cds_test,
+                                           cd_pair,
+                                           compactness_measure,
+                                           aList,
+                                           areas_vec,
+                                           borderlength_mat,
+                                           true,
+                                           pop_vec,
+                                           ssdmat,
+                                           ndists,
+                                           g,
+                                           as<arma::vec>(county_membership),
+                                           ssd_denominator);
 
       compact_new_psi += as<double>(compact_constraint["compact_new_psi"]);
       compact_old_psi += as<double>(compact_constraint["compact_old_psi"]);
-      
+
     }
     if(weight_segregation != 0.0){
-      
+
       segregation_constraint = calc_psisegregation(cds_prop, cds_test, pop_vec, cd_pair, group_pop_vec);
 
       segregation_new_psi += as<double>(segregation_constraint["segregation_new_psi"]);
-      segregation_old_psi += as<double>(segregation_constraint["segregation_new_psi"]);
-      
+      segregation_old_psi += as<double>(segregation_constraint["segregation_old_psi"]);
+
+    }
+    if(weight_vra != 0.0){
+
+      vra_constraint = calc_psivra(cds_prop, cds_test, pop_vec, cd_pair, group_pop_vec, tgt_min, tgt_other);
+
+      vra_new_psi += as<double>(vra_constraint["vra_new_psi"]);
+      vra_old_psi += as<double>(vra_constraint["vra_old_psi"]);
+
     }
     if(weight_similar != 0.0){
-      
+
       similar_constraint = calc_psisimilar(cds_prop, cds_test, cds_orig, cd_pair);
 
       similar_new_psi += as<double>(similar_constraint["similar_new_psi"]);
       similar_old_psi += as<double>(similar_constraint["similar_old_psi"]);
-      
+
     }
-    
+
     // Update cd assignments and cd populations
     cds_prop = cds_test;
     cdspop_prop = prop_cd_pops;
-    
+
     // Push back prop_partition to accepted_partitions
     for(int j = 0; j < prop_partitions.size(); j++){
       accepted_partitions.push_back(prop_partitions(j));
@@ -671,7 +719,7 @@ List make_swaps(List boundary_cc,
     if(breakp == 1){
       break;
     }
-    
+
   }
 
   // County split metric
@@ -681,49 +729,94 @@ List make_swaps(List boundary_cc,
 
     countysplit_new_psi += as<double>(countysplit_constraint["countysplit_new_psi"]);
     countysplit_old_psi += as<double>(countysplit_constraint["countysplit_old_psi"]);
-    
+
   }
+  if(weight_partisan != 0.0){
+
+    List partisan_constraint =  calc_psipartisan(cds_prop, cds_test, rvote, dvote, partisan_measure, ndists);
+
+    partisan_new_psi += as<double>(partisan_constraint["partisan_new_psi"]);
+    partisan_old_psi += as<double>(partisan_constraint["partisan_old_psi"]);
+  }
+  if(weight_minority != 0.0){
+
+    List minority_constraint =  calc_psiminority(cds_prop, cds_test,
+                                                 pop_vec, group_pop_vec,
+                                                 ndists, minorityprop);
+
+    minority_new_psi += as<double>(minority_constraint["minority_new_psi"]);
+    minority_old_psi += as<double>(minority_constraint["minority_old_psi"]);
+  }
+  if(weight_hinge != 0.0){
+    
+    List hinge_constraint =  calc_psihinge(cds_prop, cds_test,
+                                                 pop_vec, group_pop_vec,
+                                                 ndists, minorityprop);
+    
+    hinge_new_psi += as<double>(hinge_constraint["hinge_new_psi"]);
+    hinge_old_psi += as<double>(hinge_constraint["hinge_old_psi"]);
+  }
+
 
   // Multiply mh_prob by constraint values
   double energy_new = weight_population * pop_new_psi + weight_compact * compact_new_psi
-    + weight_segregation * segregation_new_psi + weight_similar * similar_new_psi
-    + weight_countysplit * countysplit_new_psi;
-  double energy_old = weight_population * pop_old_psi + weight_compact * compact_old_psi
-    + weight_segregation * segregation_old_psi + weight_similar * similar_old_psi
-    + weight_countysplit * countysplit_old_psi;
-  mh_prob = (double)mh_prob * exp(-1.0 * beta * (energy_new - energy_old));
-  
-  // Create returned list
-  List out;
-  out["proposed_partition"] = cds_prop;
-  out["mh_prob"] = mh_prob;
-  out["updated_cd_pops"] = cdspop_prop;
-  out["goodprop"] = goodprop;
-  out["energy_new"] = energy_new;
-  out["energy_old"] = energy_old;
-  if(weight_population != 0.0){
-    out["pop_new_psi"] = pop_new_psi;
-    out["pop_old_psi"] = pop_old_psi;
-  }
-  if(weight_compact != 0.0){
-    out["compact_new_psi"] = compact_new_psi;
-    out["compact_old_psi"] = compact_old_psi;
-  }
-  if(weight_segregation != 0.0){
-    out["segregation_new_psi"] = segregation_new_psi;
-    out["segregation_old_psi"] = segregation_old_psi;
-  }
-  if(weight_similar != 0.0){
-    out["similar_new_psi"] = similar_new_psi;
-    out["similar_old_psi"] = similar_old_psi;
-  }
-  if(weight_countysplit != 0.0){
-    out["countysplit_new_psi"] = countysplit_new_psi;
-    out["countysplit_old_psi"] = countysplit_old_psi;
-  }
-  
-  return out;
-  
+    + weight_segregation * segregation_new_psi + weight_vra * vra_new_psi + weight_similar * similar_new_psi
+    + weight_countysplit * countysplit_new_psi + weight_partisan * partisan_new_psi + 
+    weight_minority * minority_new_psi + weight_hinge * hinge_new_psi;
+    double energy_old = weight_population * pop_old_psi + weight_compact * compact_old_psi
+      + weight_segregation * segregation_old_psi + weight_vra * vra_old_psi + weight_similar * similar_old_psi
+      + weight_countysplit * countysplit_old_psi + weight_partisan * partisan_old_psi + 
+      weight_minority * minority_old_psi + weight_hinge * hinge_old_psi;
+      mh_prob = (double)mh_prob * exp(-1.0 * beta * (energy_new - energy_old));
+
+      // Create returned list
+      List out;
+      out["proposed_partition"] = cds_prop;
+      out["mh_prob"] = mh_prob;
+      out["updated_cd_pops"] = cdspop_prop;
+      out["goodprop"] = goodprop;
+      out["energy_new"] = energy_new;
+      out["energy_old"] = energy_old;
+      if(weight_population != 0.0){
+        out["pop_new_psi"] = pop_new_psi;
+        out["pop_old_psi"] = pop_old_psi;
+      }
+      if(weight_compact != 0.0){
+        out["compact_new_psi"] = compact_new_psi;
+        out["compact_old_psi"] = compact_old_psi;
+      }
+      if(weight_segregation != 0.0){
+        out["segregation_new_psi"] = segregation_new_psi;
+        out["segregation_old_psi"] = segregation_old_psi;
+      }
+      if(weight_vra != 0.0){
+        out["vra_new_psi"] = vra_new_psi;
+        out["vra_old_psi"] = vra_old_psi;
+      }
+      if(weight_similar != 0.0){
+        out["similar_new_psi"] = similar_new_psi;
+        out["similar_old_psi"] = similar_old_psi;
+      }
+      if(weight_countysplit != 0.0){
+        out["countysplit_new_psi"] = countysplit_new_psi;
+        out["countysplit_old_psi"] = countysplit_old_psi;
+      }
+      if(weight_partisan != 0.0){
+        out["partisan_new_psi"] = partisan_new_psi;
+        out["partisan_old_psi"] = partisan_old_psi;
+      }
+      if(weight_minority != 0.0){
+        out["minority_new_psi"] = minority_new_psi;
+        out["minority_old_psi"] = minority_old_psi;
+      }
+      if(weight_hinge != 0.0){
+        out["hinge_new_psi"] = hinge_new_psi;
+        out["hinge_old_psi"] = hinge_old_psi;
+      }
+
+
+      return out;
+
 }
 
 // Function to accept or reject swaps
@@ -731,9 +824,9 @@ int mh_decision(double mh_prob)
 {
 
   /* Inputs to function:
-     mh_prob: metropolis-hastings probability
-  */
-  
+   mh_prob: metropolis-hastings probability
+   */
+
   // Initialize decision
   int decision = 0;
 
@@ -759,24 +852,24 @@ int mh_decision(double mh_prob)
 
 // Function that applies the Geyer Thompson algorithm for simulated tempering
 List changeBeta(arma::vec betavec,
-		double beta,
-		double constraint,
-		NumericVector weights,
-		int adjswap = 1)
+                double beta,
+                double constraint,
+                NumericVector weights,
+                int adjswap = 1)
 {
-  
-  /* Inputs to function 
-     betavec: vector of possible betas
 
-     beta: current value of the beta constraint
+  /* Inputs to function
+   betavec: vector of possible betas
 
-     constraint: the evaluation of the constraint on the current plan
+   beta: current value of the beta constraint
 
-     weights: priors on the betas
+   constraint: the evaluation of the constraint on the current plan
+
+   weights: priors on the betas
+
+   adjswap: flag - do we want adjacent swaps? default to 1
+   */
 
-     adjswap: flag - do we want adjacent swaps? default to 1
-  */
-  
   // Find beta in betavec
   arma::uvec findBetaVec = find(betavec == beta);
   int findBeta = findBetaVec(0);
@@ -811,12 +904,12 @@ List changeBeta(arma::vec betavec,
       wi = weights(findBeta);
       arma::vec betaswitch = runif(1);
       if(betaswitch(0) < .5){
-	propBeta = betavec(findBeta - 1);
-	wj = weights(findBeta - 1);
+        propBeta = betavec(findBeta - 1);
+        wj = weights(findBeta - 1);
       }
       if(betaswitch(0) >= .5){
-	propBeta = betavec(findBeta + 1);
-	wj = weights(findBeta + 1);
+        propBeta = betavec(findBeta + 1);
+        wj = weights(findBeta + 1);
       }
     }
   } else{
@@ -829,7 +922,7 @@ List changeBeta(arma::vec betavec,
     arma::vec rand_randindex = runif(1, 0, 1000000000);
     int randindex = fmod(rand_randindex(0), betaLoc);
 
-    // Weight wi 
+    // Weight wi
     wi = weights(findBeta);
 
     // Draw the proposed beta value
